@@ -22,9 +22,15 @@ from nwdiag.drawer import DiagramDraw
 from blockdiag.utils.rst import directives
 
 
-format = 'PNG'
-antialias = False
-fontpath = None
+directive_options_default = dict(format='PNG',
+                                 antialias=False,
+                                 fontpath=None,
+                                 outputdir=None,
+                                 nodoctype=False,
+                                 noviewbox=False,
+                                 inline_svg=False,
+                                 ignore_pil=False)
+directive_options = {}
 
 
 class nwdiag(nodes.General, nodes.Element):
@@ -41,19 +47,32 @@ class NwdiagDirective(directives.BlockdiagDirective):
     name = "nwdiag"
     node_class = nwdiag
 
+    @property
+    def global_options(self):
+        return directive_options
+
     def node2diagram(self, node):
         tree = parser.parse_string(node['code'])
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
-        filename = self._filename(node)
+        filename = self.image_filename(node)
         fontpath = self.detectfont()
-        drawer = DiagramDraw(format, diagram, filename,
-                             font=fontpath, antialias=antialias)
+        format = self.global_options['format'].lower()
 
-        if not os.path.isfile(filename):
+        if format == 'svg' and self.global_options['inline_svg'] is True:
+            filename = None
+
+        kwargs = dict(self.global_options)
+        del kwargs['format']
+        drawer = DiagramDraw(format, diagram, filename, **kwargs)
+
+        if filename is None or not os.path.isfile(filename):
             drawer.draw()
-            drawer.save()
+            content = drawer.save(None)
+
+            if format == 'svg' and self.global_options['inline_svg'] is True:
+                return nodes.raw('', content.encode('utf-8'), format='html')
 
         size = drawer.pagesize()
         options = node['options']
@@ -61,7 +80,7 @@ class NwdiagDirective(directives.BlockdiagDirective):
             ratio = float(options['maxwidth']) / size[0]
             thumb_size = (options['maxwidth'], size[1] * ratio)
 
-            thumb_filename = self._filename(node, prefix='_thumb')
+            thumb_filename = self.image_filename(node, prefix='_thumb')
             if not os.path.isfile(thumb_filename):
                 drawer.filename = thumb_filename
                 drawer.draw()
@@ -78,9 +97,9 @@ class NwdiagDirective(directives.BlockdiagDirective):
 
 
 def setup(**kwargs):
-    global format, antialias, fontpath
-    format = kwargs.get('format', 'PNG')
-    antialias = kwargs.get('antialias', False)
-    fontpath = kwargs.get('fontpath', None)
+    global directive_options, directive_options_default
+
+    for key, value in directive_options_default.items():
+        directive_options[key] = kwargs.get(key, value)
 
     rst.directives.register_directive("nwdiag", NwdiagDirective)
